@@ -9,7 +9,7 @@ import json
 import time
 import random
 
-from charset_normalizer import detect
+from chardet import detect
 from httpx import Client, Response
 from loguru import logger
 
@@ -36,31 +36,31 @@ class BaseRequests(object):
         headers=UserAgent(),
         method: str = "get",
         proxies: dict = None,
-        proxy_type: str = "random",
+        proxy_url: str = None,
         http2: bool = False,
         encoding: str = None,
         retry: int = 3,
         **kwargs
     ) -> Response:
         """
-        内置ali_waf & 知道创宇加速乐解密
+        内置ali_waf & 加速乐解密
 
         :param url: 请求链接
         :param session: 维持session可从外部传入
         :param headers: 请求头
         :param method:  具体请求方式
-        :param proxies: ip代理，失效自动切换
-        :param proxy_type:  代理类型，默认取随机
+        :param proxies: ip代理，配合proxy_url可失效自动切换
+        :param proxy_url:  获取代理链接
         :param http2:   是否使用http2.0协议
-        :param encoding:   指定编码，默认detect解析，效果同requests的apparent_encoding
         :param retry:   请求重试次数，默认3次
+        :param encoding:   指定编码，默认detect解析，效果同requests的apparent_encoding
         :param kwargs:  请求时需携带的其他参数
         :return: Response
         :exception: 1.代理失效&超过重试次数返回None 2.waf或加速乐解密失败返回None
         """
         for _ in range(retry):
             try:
-                proxies = proxies if proxies else get_proxies(proxy_type)
+                proxies = proxies if proxies else get_proxies(proxy_url, http2=True)
                 session = session or Client(
                     http2=http2,
                     headers=headers,
@@ -81,7 +81,7 @@ class BaseRequests(object):
                     timeout=kwargs.get("timeout", 20),
                     follow_redirects=kwargs.get("allow_redirects", False)
                 )
-                response.encoding = encoding if encoding else detect(response.content)['encoding']
+                response.encoding = encoding if encoding else detect(response.content)['encoding']  # chardet 更准确
                 if 200 <= response.status_code < 300 or response.status_code == 412:
                     if 'arg1' in response.text:
                         acw_tc_cookie = f'acw_tc={session.cookies.get("acw_tc")};'
